@@ -66,7 +66,7 @@ S20:
      ......EXIT
 */
         if(s <= 0.0) goto S40;
-        *(a+j-1+(j-1)*lda) = sqrt(s);
+        *(a+j-1+(j-1)*lda) = sqrtf(s);
     }
     *info = 0;
 S40:
@@ -139,7 +139,7 @@ static long i,icount,info,j,D2,D3,D4,D5;
     Rprintf("P nonpositive in SETGMN: please report to <brett.mcclintock@noaa.gov> \n");
     return;
 S10:
-    *parm = p;
+    *parm = (float) p;
 /*
      PUT P AND MEANV INTO PARM
 */
@@ -190,7 +190,7 @@ static float ranf;
      4.656613057E-10 is 1/M1  M1 is set in a data statement in IGNLGI
       and is currently 2147483563. If M1 changes, change this also.
 */
-    ranf = ignlgi()*4.656613057E-10;
+    ranf = (float) ignlgi() * 4.656613057E-10f;
     return ranf;
 }
 
@@ -224,31 +224,31 @@ float snorm(void)
 */
 {
 static float a[32] = {
-    0.0,3.917609E-2,7.841241E-2,0.11777,0.1573107,0.1970991,0.2372021,0.2776904,
-    0.3186394,0.36013,0.4022501,0.4450965,0.4887764,0.5334097,0.5791322,
-    0.626099,0.6744898,0.7245144,0.7764218,0.8305109,0.8871466,0.9467818,
-    1.00999,1.077516,1.150349,1.229859,1.318011,1.417797,1.534121,1.67594,
-    1.862732,2.153875
+    0.0,3.917609E-2f,7.841241E-2f,0.11777f,0.1573107f,0.1970991f,0.2372021f,0.2776904f,
+    0.3186394f,0.36013f,0.4022501f,0.4450965f,0.4887764f,0.5334097f,0.5791322f,
+    0.626099f,0.6744898f,0.7245144f,0.7764218f,0.8305109f,0.8871466f,0.9467818f,
+    1.00999f,1.077516f,1.150349f,1.229859f,1.318011f,1.417797f,1.534121f,1.67594f,
+    1.862732f,2.153875f
 };
 static float d[31] = {
-    0.0,0.0,0.0,0.0,0.0,0.2636843,0.2425085,0.2255674,0.2116342,0.1999243,
-    0.1899108,0.1812252,0.1736014,0.1668419,0.1607967,0.1553497,0.1504094,
-    0.1459026,0.14177,0.1379632,0.1344418,0.1311722,0.128126,0.1252791,
-    0.1226109,0.1201036,0.1177417,0.1155119,0.1134023,0.1114027,0.1095039
+    0.0,0.0,0.0,0.0,0.0,0.2636843f,0.2425085f,0.2255674f,0.2116342f,0.1999243f,
+    0.1899108f,0.1812252f,0.1736014f,0.1668419f,0.1607967f,0.1553497f,0.1504094f,
+    0.1459026f,0.14177f,0.1379632f,0.1344418f,0.1311722f,0.128126f,0.1252791f,
+    0.1226109f,0.1201036f,0.1177417f,0.1155119f,0.1134023f,0.1114027f,0.1095039f
 };
 static float t[31] = {
-    7.673828E-4,2.30687E-3,3.860618E-3,5.438454E-3,7.0507E-3,8.708396E-3,
-    1.042357E-2,1.220953E-2,1.408125E-2,1.605579E-2,1.81529E-2,2.039573E-2,
-    2.281177E-2,2.543407E-2,2.830296E-2,3.146822E-2,3.499233E-2,3.895483E-2,
-    4.345878E-2,4.864035E-2,5.468334E-2,6.184222E-2,7.047983E-2,8.113195E-2,
-    9.462444E-2,0.1123001,0.136498,0.1716886,0.2276241,0.330498,0.5847031
+    7.673828E-4f,2.30687E-3f,3.860618E-3f,5.438454E-3f,7.0507E-3f,8.708396E-3f,
+    1.042357E-2f,1.220953E-2f,1.408125E-2f,1.605579E-2f,1.81529E-2f,2.039573E-2f,
+    2.281177E-2f,2.543407E-2f,2.830296E-2f,3.146822E-2f,3.499233E-2f,3.895483E-2f,
+    4.345878E-2f,4.864035E-2f,5.468334E-2f,6.184222E-2f,7.047983E-2f,8.113195E-2f,
+    9.462444E-2f,0.1123001f,0.136498f,0.1716886f,0.2276241f,0.330498f,0.5847031f
 };
 static float h[31] = {
-    3.920617E-2,3.932705E-2,3.951E-2,3.975703E-2,4.007093E-2,4.045533E-2,
-    4.091481E-2,4.145507E-2,4.208311E-2,4.280748E-2,4.363863E-2,4.458932E-2,
-    4.567523E-2,4.691571E-2,4.833487E-2,4.996298E-2,5.183859E-2,5.401138E-2,
-    5.654656E-2,5.95313E-2,6.308489E-2,6.737503E-2,7.264544E-2,7.926471E-2,
-    8.781922E-2,9.930398E-2,0.11556,0.1404344,0.1836142,0.2790016,0.7010474
+    3.920617E-2f,3.932705E-2f,3.951E-2f,3.975703E-2f,4.007093E-2f,4.045533E-2f,
+    4.091481E-2f,4.145507E-2f,4.208311E-2f,4.280748E-2f,4.363863E-2f,4.458932E-2f,
+    4.567523E-2f,4.691571E-2f,4.833487E-2f,4.996298E-2f,5.183859E-2f,5.401138E-2f,
+    5.654656E-2f,5.95313E-2f,6.308489E-2f,6.737503E-2f,7.264544E-2f,7.926471E-2f,
+    8.781922E-2f,9.930398E-2f,0.11556f,0.1404344f,0.1836142f,0.2790016f,0.7010474f
 };
 static long i;
 static float snorm,u,s,ustar,aa,w,y,tt;
@@ -256,7 +256,7 @@ static float snorm,u,s,ustar,aa,w,y,tt;
     s = 0.0;
     if(u > 0.5) s = 1.0;
     u += (u-s);
-    u = 32.0*u;
+    u = 32.0f*u;
     i = (long) (u);
     if(i == 32) i = 31;
     if(i == 0) goto S100;
@@ -282,7 +282,7 @@ S60:
 */
     u = ranf();
     w = u*(*(a+i)-aa);
-    tt = (0.5*w+aa)*w;
+    tt = (0.5f*w+aa)*w;
     goto S80;
 S70:
     tt = u;
@@ -306,10 +306,10 @@ S110:
 S120:
     u += u;
     if(u < 1.0) goto S110;
-    u -= 1.0;
+    u -= 1.0f;
 S140:
     w = u**(d+i-1);
-    tt = (0.5*w+aa)*w;
+    tt = (0.5f*w+aa)*w;
     goto S160;
 S150:
     tt = u;
@@ -514,7 +514,7 @@ static long mltmod,a0,a1,k,p,q,qh,rh;
     if(!(a <= 0 || a >= m || s <= 0 || s >= m)) goto S10;
     Rprintf(" a, m, s out of order in mltmod - ABORT!: please report to <brett.mcclintock@noaa.gov> \n");
     Rprintf(" mltmod requires: 0 < a < m; 0 < s < m: please report to <brett.mcclintock@noaa.gov> \n");
-    return(NA_REAL);
+    return(NA_INTEGER);
 S10:
     if(!(a < h)) goto S20;
     a0 = a;
